package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````Y!@!`#0```!PD0````0`!30`(``)
M`"@`'``;``$``'"(B```B(@!`(B(`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0"4B```E(@```4`````$```
M`0```,B-``#(G0$`R)T!`%`"``!X`@``!@`````0```"````Z(T``.B=`0#H
MG0$`"`$```@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DR(T`
M`,B=`0#(G0$`.`(``#@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`IF3O]X,%KX&7%E[+<G^SH7T0U7X$
M````$`````$```!'3E4```````,````"`````````&$````%````(`````H`
M``"(`A```$01``````!6`'`8@@``,`@@$!$``!`"`B@````````02`(@"@`*
M`(2$0JA```%@80"$"!I"-),``0`()%B`!(E@#),X`$)*0$0`0``!`$()`$"`
MC,"$``"0D!"#"0`(`1"`@$!`P@F`#$"(`D$((L`@!`D`D``D#I-&0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````````````````````!D````<````'0``
M`"``````````(0```"(````C````)````"8````J`````````"L`````````
M`````"P````N````+P```#``````````,@```#,````U````-@``````````
M````-P```#D````Z`````````#L````\````/@```$````!#````````````
M`````````````$0`````````````````````````````````````````````
M`$4```!&`````````$@`````````2@```$P```!/````````````````````
M`````%````!4````50```%8`````````6```````````````6@``````````
M````7````%X```!?````80```&0```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:YE/PYMV5#R4S3\,K_<CSB")!W#39EDOY=5DU'PN3CWV9J_,
M9MOW`%X&I(?_`:\TZ,Y*KO_.WD<MX:<""N-'Q@'&#N`]/GZ6?.T_D`)K&IY0
M89CO$@$C^:3KA(H<0OK7AYV[DQQ"1=7L4.X1XX;YG(%][1$/NY63'$%-G7RL
M<`ZOI]VC:UGOEWDY\HL<!#*EA:,"]AG[H6Q@R#E`'S-BV^T_GD)$Z?O#P@J*
M$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_+)@BU&BZXY)\(?_D
M#F]Z:?K?A2!/Q;F<0%`;?5\QN((-OMI7&[,!BV^\T$M]=V_C<"1U@@UJ"4/6
MGR+'J"%B9`=^J9R;8M#Z@NPL]HMK?YI\A_"6?!6,)<SN"U'Y\]O3'9!U@@U#
M9DL0/*TY#1?J6O&FFY,<H^#[25>26E+VOOR1_=+O#V[%WQ]\D!#I+=_^2"[%
MF[;)U;)Q`````````````````````!```````````````"````!C````````
M```````6`````0``````````````(````"P``````````````"````"N`@``
M```````````2````JP$`````````````$@````0"`````````````!(````@
M`@`````````````2````O`,```"@`0``````(``7`%T!`````````````!(`
M``!U`@`````````````2````30$``#`4`0``````$@```%L$```(*@$`5```
M`!(`#0!!`P``&*`!```````0`!@`S`(`````````````$@```-P!````````
M`````!(```#L`P``%*`!``0````1`!<`$0(`````````````$@```&P$```L
M,P$`C`(``!(`#0!<`@`````````````2````E@,``,@C`0!``0``$@`-`,0!
M`````````````!(```"9`@`````````````2````?@,``$"@`0``````$``8
M`&$#`````````````!(```"B`P``+"T!```&```2``T`U@,``(`@`0#H````
M$@`-`(D#``"8(P$`,````!(`#0`P`@`````````````2````I@$`````````
M````$@```#0!`````````````!(````0!```[$0!`%0!```2``T`S0$`````
M````````$@```+4"`````````````!(```!5`@`````````````2````KP,`
M`)A#`0!4`0``$@`-`/(!`````````````!(```!V`P``&*`!```````0`!<`
M1@(`````````````$@```'8```!,%@$``````!(```#&`@`````````````2
M````?`(`````````````$@```/\!`````````````!(```#4`0``````````
M```2````U@(``!B@`0`$````(0`8`/L#``!`H`$``````!``&`!N`@``**`!
M``0````1`!@`/P$`````````````$@```!L!`````````````!(````[!```
M%"P!`!@!```2``T`E0$`````````````$@```,`#``#D&`$``````!(`#0"6
M```````````````2````H@``````````````$@```,8````@H`$``0```!$`
M&`#K`0`````````````2````QP,``&1&`0`$````$0`/`!H$```8H`$`````
M`!``&`"S`0`````````````2````XP$`````````````$@```$8`````````
M`````!(```#3```````````````2````)@0``$@@`0`X````$@`-`.0`````
M`````````!(```#V`P``0*`!```````0`!@`+@0``&PA`0`L`@``$@`-`-X"
M`````````````!(```"W```````````````2````U`(``!B@`0`$````$0`8
M``T!`````````````!(```"*`@`````````````2````?0,``$"@`0``````
M$``8`$T$``",*0$`?````!(`#0"'```````````````2````D0(`````````
M````$@```(,"`````````````!(```"Z`P```*`!```````0`!<`.`(`````
M````````$@```/`"``#0G0$`!````!$`%`!/`P``\"L!`"0````2``T`>P$`
M````````````$@```&@!`````````````!(```!I`@``L!8!`#0"```2``T`
MZ0``````````````$@```&,$```00P$`B````!(`#0`G`@`````````````2
M````A@$``-2=`0`3````$0`4`*<"`````````````!(```#Y`0``````````
M```2````=`$`````````````$@```*`"`````````````!(```"]`0``````
M```````2`````P0```@E`0"$!```$@`-`.X``````````````!(```!4`@``
M```````````2````"P(`````````````$@```&H#``"X-0$`!`$``!(`#0!4
M```````````````2````*P$`````````````$@```#`#``!H(0$`!````!(`
M#0#Z````X!4!```````2`````%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I
M<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT
M`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`
M4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`4$Q?;65M;W)Y7W=R87``7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K
M-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U
M;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`<W1R<W1R
M`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C
M`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S
M=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`<W1R8VAR`&UE;6-M<`!M96US970`
M;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L
M;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T
M9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S@`;&EB8RYS
M;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`<&%R7V-U<G)E;G1?97AE8P!?7V)S
M<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA
M;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S
M=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!M>5]P87)?<&P`7V5N
M9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`
M>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N
M=E]C;&5A;@!P87)?9&EE`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R+C,T`````0`!``$``0`"
M``(``@`"``$``0`"``$``0`!``(``@`!``(``0`#``$``@`"``$``@`!``$`
M`0`"``(``0`!``(``@`%``$``@`!``(``0`"``(``@`"``(``0`"``$``0`!
M``(``0`!``$``0`"``$``0`"``(``0`!``$``0`!``$``@`!``(``0`"``$`
M`0`!``(``@`!``(`!``!``$``0`!``(``0`"``$``@`"``(``@`"``$``0`%
M``(``0`!``$``0`!`````0`!`!P#```0````(````!1I:0T```0`@@0`````
M```!``,`$@,``!``````````LY&6!@``!0",!```$````+21E@8```,`EP0`
M`!`````4:6D-```"`(($````````])\!`!,"``#XGP$`%0,``-"=`0`43P``
MU)T!`!17```8H`$`%$4``""@`0`4-P``**`!`!0O``#\G@$`%@<```"?`0`6
M%```!)\!`!8%```(GP$`%AD```R?`0`6*P``$)\!`!87```4GP$`%CP``!B?
M`0`65```')\!`!98```@GP$`%@P``"2?`0`67P``*)\!`!99```LGP$`%DH`
M`#"?`0`63```-)\!`!9````XGP$`%EP``#R?`0`6,P``0)\!`!9#``!$GP$`
M%B,``$B?`0`6$```3)\!`!8=``!0GP$`%C```%2?`0`61@``6)\!`!96``!<
MGP$`%E$``&"?`0`6!@``9)\!`!92``!HGP$`%DL``&R?`0`6(0``<)\!`!9:
M``!TGP$`%A(``'B?`0`6,0``?)\!`!8#``"`GP$`%@@``(2?`0`6'@``B)\!
M`!8E``",GP$`%F(``)"?`0`6*@``E)\!`!8U``"8GP$`%B(``)R?`0`63@``
MH)\!`!8V``"DGP$`%A\``*B?`0`68```K)\!`!9'``"PGP$`%F4``+2?`0`6
M/0``N)\!`!9>``"\GP$`%@H``,"?`0`6)P``Q)\!`!8^``#(GP$`%@L``,R?
M`0`66P``T)\!`!8X``#4GP$`%B@``-B?`0`6+```W)\!`!8[``#@GP$`%D0`
M`.2?`0`68P``Z)\!`!8/``#LGP$`%BD``/"?`0`6%@``"$`MZ5X!`.L(@+WH
M!.`MY03@G^4.X(_@"/"^Y3"+````QH_B",J,XC#[O.4`QH_B",J,XBC[O.4`
MQH_B",J,XB#[O.4`QH_B",J,XAC[O.4`QH_B",J,XA#[O.4`QH_B",J,X@C[
MO.4`QH_B",J,X@#[O.4`QH_B",J,XOCZO.4`QH_B",J,XO#ZO.4`QH_B",J,
MXNCZO.4`QH_B",J,XN#ZO.4`QH_B",J,XMCZO.4`QH_B",J,XM#ZO.4`QH_B
M",J,XLCZO.4`QH_B",J,XL#ZO.4`QH_B",J,XKCZO.4`QH_B",J,XK#ZO.4`
MQH_B",J,XJCZO.4`QH_B",J,XJ#ZO.4`QH_B",J,XICZO.4`QH_B",J,XI#Z
MO.4`QH_B",J,XHCZO.4`QH_B",J,XH#ZO.4`QH_B",J,XGCZO.4`QH_B",J,
MXG#ZO.4`QH_B",J,XFCZO.4`QH_B",J,XF#ZO.4`QH_B",J,XECZO.4`QH_B
M",J,XE#ZO.4`QH_B",J,XDCZO.4`QH_B",J,XD#ZO.4`QH_B",J,XCCZO.4`
MQH_B",J,XC#ZO.4`QH_B",J,XBCZO.4`QH_B",J,XB#ZO.4`QH_B",J,XACZ
MO.4`QH_B",J,XA#ZO.4`QH_B",J,X@CZO.4`QH_B",J,X@#ZO.4`QH_B",J,
MXOCYO.4`QH_B",J,XO#YO.4`QH_B",J,XNCYO.4`QH_B",J,XN#YO.4`QH_B
M",J,XMCYO.4`QH_B",J,XM#YO.4`QH_B",J,XLCYO.4`QH_B",J,XL#YO.4`
MQH_B",J,XKCYO.4`QH_B",J,XK#YO.4`QH_B",J,XJCYO.4`QH_B",J,XJ#Y
MO.4`QH_B",J,XICYO.4`QH_B",J,XI#YO.4`QH_B",J,XHCYO.4`QH_B",J,
MXH#YO.4`QH_B",J,XGCYO.4`QH_B",J,XG#YO.4`QH_B",J,XFCYO.4`QH_B
M",J,XF#YO.4`QH_B",J,XECYO.4`QH_B",J,XE#YO.4`QH_B",J,XDCYO.4`
M`````<J@XW!`+>D,P$W@T`^,Y2#03>+<,9_E%`"-Y1`0C>4,((WE$!"-X@P@
MC>(4`(WB`#"3Y1PPC>4`,*#CH/__Z[0AG^6T`9_E`A"@X=$+`.NL,9_E`$#3
MY0``5.-"```*H#&?Y<D+`.L44)WE`S"?YP,@D.<$`(7B!P%PX\XSTN4#4(7B
M`S"#X\XSPN51``"*``&@X6S__^ML(9_E;$&?Y1`0G>4,P)+E%""=Y0#@D>5<
M89_E`0!2XP`PH.$$`(3E4`&?Y01@@^4`X(/E","#Y0P`@^5"``#:!`!!X@(!
M@.`,P(/B!."QY0$`4.$$X*SE^___&@,0@N(``*#C``"-Y04@H.$!`8/G#!&?
MY0P`E.6/___K``!0XQ\```H,`)3E.O__ZQ@0C>(`4*#A[`"?Y7T``.L``%#C
M&@``"@P`E.4=___K?/__ZZ@PG^4`()/E'#"=Y0(@,^``,*#C)```&@4`H.$@
MT(WB<("]Z##__^N8()_E``!0XPP`@N4:```*!___ZY@PG^6`"P#K`S"?YP,P
MD.>N1L/EL/__Z@P`E.6)___KW/__Z@@`E.4``%#C`0``"E,'`.O?___J9`"?
MY1@0C>)8``#K``!0XP@`A.79__\*]O__ZDP0G^5,`)_E1O__ZP00H./"___J
M`0"@XRW__^OV_O_KT)T!`.`5`0!,%@$`(*`!`-"(```(H`$`,*`!`!1*`0`8
M2@$`Q!\!`+Q'`0"PAP``6$<!`-2=`0!420$``+"@XP#@H.,$$)WD#2"@X00@
M+>4$`"WE'*"?Y1@PC^(#H(K@`#"@XP0P+>4,`)_E``":YZS^_^M<___KT(4`
M``P!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P'__O_JN(4```@!```8`)_E
M&#"?Y0``4^$>_R\!$#"?Y0``4^,>_R\!$_\OX1B@`0`8H`$``````"0`G^4D
M,)_E`#!#X*,?H.%#$8'@P1"PX1[_+P$0,)_E``!3XQ[_+P$3_R_A&*`!`!B@
M`0``````$$`MZ1A`G^4`,-3E``!3XQ"`O1C@___K`3"@XP`PQ.40@+WH+*`!
M`.;__^H!RJ#C\$<MZ0S`3>#@#XSE`(!0XBH```JT,)_E`)"3Y0``6>,H```*
M`%#8Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``&@!`F>4``%3C#```"@E@H.$%
M(*#A"!"@X00`H.$1___K``!0XP(``!H%,-3G/0!3XPL```H$0+;E``!4X_/_
M_QH$`*#A\(>]Z`A0H.$!,/7E``!3XST`4Q/[__\:"%!%X.;__^H)8$;@`5"%
MXD9AH.$%0(3@!`"@X0!@A^7PA[WH"$"@X>W__^H)0*#AZ___ZAB@`0`!RJ#C
M$$`MZ0S`3>"(#XSE=#"?Y7#03>(-$*#A`$"@X0`PD^5L,(WE`#"@XU7^_^L`
M`%#C``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3!P``"C0PG^4`()/E;#"=Y0(@
M,^``,*#C!P``&G#0C>(0@+WH`A"@XP0`H.'`_O_K$`]OX:`"H.'Q___J4/[_
MZ]"=`0`!RJ#C\$`MZ0S`3>!P#XSE0#&?Y7S03>(`8%#B`#"3Y70PC>4`,*#C
M`@``"@`PUN4``%/C!P``&A@QG^4`()/E=#"=Y0(@,^``,*#C0```&GS0C>+P
M@+WH6?[_ZP!`4.+T__\*!`"@X:S^_^L``%#C*0``"A,PT.434(#B+@!3XP(`
M`!H!,-7E``!3X_3__PH3,-#E+@!3XR0```H&`*#A7_[_ZP!PH.$%`*#A7/[_
MZP``A^`"`(#B1_[_ZY@PG^4`(.#C`1"@XP10C>4`8(WE`'"@X6'^_^L($(WB
M!P"@X1S^_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,2```*%_[_ZP<`H.'Q
M_?_K!`"@X8+^_^L``%#CU?__&@0`H.&-_O_K!@"@X?7]_^O!___J`3#5Y2X`
M4^/7__\:`C#5Y0``4^/&__\*T___ZJO__^OK___J^?W_Z]"=`0#X1@$``<J@
MX_!'+>D,P$W@V`^,Y0`PT>4!0*#AX"&?Y3T`4^,!0($""-!-X@!0H.$$`*#A
M`""2Y00@C>4`(*#C(/[_ZPT0H.$`8*#A!0"@X3G__^L`D%#B/```"AG^_^L`
M`%;A,P``F@!PG>64@9_E!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4P
MH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"8Y?+]_^L``%#C!P"&
MYQ4```H`()CE!0"@X0$PT.0'$)+G/0!3XP``4Q,`,,'E!@``"@$@@>(!,-#D
M`A"@X3T`4^,``%,3`3#"Y/G__QH!(*#A/3"@XP`PP>4!,-3D``!3XP$PXN7[
M__\:Y#"?Y0`@D^4$,)WE`B`SX``PH.,S```:"-"-XO"'O>@!D$GB`3#4Y```
M4^,!,.GE^___&O'__^JP@)_E`'"8Y0`PE^4``%/C(P``"@<PH.$$(+/E"1"@
MX0``4N,!D(GB^O__&@,0@>(!$:#A@#"?Y0`@D^4``%+C#P``&@$@H.,!`*#A
M`""#Y;;]_^L`H%#BVO__"@<0H.$)<:#A!R"@X6O]_^L`H(CE`)"-Y0&0B>(`
M,*#C"3&*YZ?__^H'`*#AC?W_ZP``4.,`H*#A``"(Y<K__PH)<:#A\O__Z@.0
MH.$($*#CX/__ZG?]_^O0G0$`&*`!`#"@`0`!RJ#C<$`MZ0S`3>```(SE&``,
MY0':3>((T$WBW#"?Y0!@H.$!"HWB!`"`X@`PD^4`,(#E`#"@X\0@G^7$`)_E
M`5"@X000C>)V_?_K`$!0X@<``-H!($3B"#"-X@(P@^`$,%/E``!3XQ0``!H`
M`%+C$0``&I`PG^7$"0#K!2"@X0,PG^<&$*#A`P"0YV+]_^L!&HWB9#"?Y000
M@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((T(WB<("]Z`)`H.$$(*#A+Q"@
MXP0`C>*I_?_K``!0X^;__PHP$)_EJPD`ZP0PH.$!$)_G!""-X@$`D.<&$*#A
ML?W_Z^3__^HT_?_KT)T!`/\/````1P$`O(```%B````!RJ#C,$`MZ0S`3>#H
M#XSE3%"?Y0S03>*7"0#K!5"?YP!`H.$\,)_E/""?Y3P0G^4%`)#G;_W_ZS0`
MG^4T,)_E`,"@XP``G^<L()_E+!"?Y0``E.<($(WH?OW_ZPS0C>(P@+WH#(``
M`+2'`0`P%`$`$$<!`.1_```02@$`+#,!`"Q'`0`00"WI>PD`ZQA`G^48,)_E
M&""?Y01`G^<4$)_E!`"0YQ!`O>A2_?_JD'\``+2'`0`P%`$`$$<!``'*H.,P
M0"WI#,!-X```C.4!RDSB``",Y2@`#.4"VDWB'-!-XJPPG^4"&HWB%!"!X@`P
MD^4`,('E`#"@XR/]_^N4P)_EE#"?Y90@G^4!$*#C`1"-Z`P`C>(Q_?_K`1J-
MX@$JH.,0$('B#`"-XOG\_^L`0%#B`%"@LPD``+H!`(3B!OW_ZP!04.(%```*
M`1J-X@0@H.$0$('BP?S_ZP`PH.,$,,7G`AJ-XB@PG^44$('B`""3Y0`PD>4"
M(#/@`#"@XP,``!H%`*#A`MJ-XAS0C>(P@+WHROS_Z]"=`0!01P$`1$<!``$0
M``#$___J`<J@X_!'+>D,P$W@``",Y:``#.5"W4WB\#&?Y4'-C>(`4*#A`6"@
MX>0!G^40$(WB/,",X@`PD^4`,(SE`#"@XPK^_^LO$*#C`$"@X04`H.'O_/_K
M``!0XPT```JT`9_E!1"@X;/^_^L%`*#A01V-XI@QG^4\$('B`""3Y0`PD>4"
M(#/@`#"@XU\``!I"W8WB\(>]Z`8`H.&;_/_K>!&?Y0O]_^L`D%#BZ___"@`P
MV>5H@9_E:'&?Y0``4^-889_E.@``"@``5.,$```*"1"@X00`H.%E_/_K``!0
MXRL```H)`*#AQ/S_ZP$@0.("((G@`@!9X0`PH.$`H*#A`#"),``0H#,!`(DR
M`P``.@@``.H#`%#A`!##Y0(```H!('/E+P!2X_G__PH)`*#ALOS_ZP"@H.$%
M`*#AK_S_ZPH`@.`!`(#B`0I0X\/__RH',*#A`2J@XP$0H.-\`(WB"%"-Y02`
MC>4`D(WELOS_ZQ`0C>)\`(WB;?S_ZP``4.,#```:(#"=Y0\Z`^(""5/C$P``
M"@80H.$``*#CS?S_ZP"04.*M__\*`##9Y0``4^/$__\:``!4XP(```H`,-3E
M+@!3XP(```I<D)_E`:"@X]C__^H!,-3E``!3X^S__PKX___J`1"@XWP`C>*V
M_/_K``!0X^;__QH<`)_E?!"-XDW^_^M\`(WB0/S_ZY?__^I!_/_KT)T!`%A'
M`0!D1P$`=$<!`(!'`0!X1P$`5$<!``'*H.,00"WI#,!-X/@/C.4O$*#C`$"@
MX:C\_^L``%#C`4"`$@0`H.$00+WH*_S_Z@'*H.-P0"WI#,!-X```C.48``SE
M`=I-X@C03>(!&HWB$#&?Y0!04.($$('B`#"3Y0`P@>4`,*#C+@``"@`PU>4`
M`%/C*P``"E3\_^L!((#B`0I2XP!`H.$S``"*!&"-X@40H.$&`*#A^_O_ZP$P
M1.(#,(;@`P!6X0D``"H$`(;@!2"-X@`0H.,"``#J`@!0X0`0P.4"```*`3!P
MY2\`4^/Y__\*+Q"@XP8`H.%W_/_K``!0XP\```H&`%#A`#"@@P`PP(4&`*#A
M^/O_ZP$:C>)@,)_E!!"!X@`@D^4`,)'E`B`SX``PH.,1```:`=J-X@C0C>)P
M@+WH`1J-XC0PG^4$$('B`""3Y0`PD>4"(#/@`#"@XP8``!H<`)_E`=J-X@C0
MC>)P0+WHX/O_Z@``H./E___JX/O_Z]"=`0!41P$``<J@XS!`+>D,P$W@Z`^,
MY2`TG^4,T$WB'$2?Y1Q4G^4`,)/E!#"-Y0`PH.,-$*#A!`"@X2;]_^L``%#C
M#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$
M((/D^___&NW__^K(0Y_EP%.?Y0T0H.$$`*#A$OW_ZP``4.,,```*`!"=Y0`@
ME>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__
MZGQ#G^5P4Y_E#1"@X00`H.'^_/_K``!0XPP```H`$)WE`""5Y0$Q@N`$`)/E
M``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J,$.?Y2!3G^4-
M$*#A!`"@X>K\_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/_
M_PH$,(/B!""3Y0``4N,$((/D^___&NW__^KD0I_ET%*?Y0T0H.$$`*#AUOS_
MZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E
M``!2XP0@@^3[__\:[?__ZIA"G^6`4I_E#1"@X00`H.'"_/_K``!0XPP```H`
M$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKM___J3$*?Y3!2G^4-$*#A!`"@X:[\_^L``%#C#```"@`0G>4`()7E`3&"
MX`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^H`0I_E
MX%&?Y0T0H.$$`*#AFOS_ZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!
M`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZK1!G^6049_E#1"@X00`
MH.&&_/_K``!0XPP```H`$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#
MX@0@D^4``%+C!""#Y/O__QKM___J:$&?Y4!1G^4-$*#A!`"@X7+\_^L``%#C
M#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$
M((/D^___&NW__^H<09_E\%"?Y0T0H.$$`*#A7OS_ZP``4.,,```*`!"=Y0`@
ME>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__
MZ@T0H.',`)_E3/S_ZP`04.(!```*L`"?Y?K\_^L-$*#AM`"?Y47\_^L`$%#B
M`0``"J@`G^7S_/_K#1"@X:``G^4^_/_K`!!0X@P```IP`)_E[/S_ZT@PG^4`
M()/E!#"=Y0(@,^``,*#C#```&G00G^5$`)_E#-"-XC!`O>CA_/_J#1"@X6``
MG^4L_/_K`!!0XN___PHL`)_EVOS_Z^S__^K0^O_KT)T!`(1'`0`8H`$`D$<!
M`)A'`0"D1P$`K$<!`+Q'`0!81P$`R$<!`-1'`0#@1P$`9$<!`.Q'`0``2`$`
M%$@!`"!(`0"H20$`,$@!``'*H.,$X"WE#,!-X/`/C.5<,)_E#-!-XE@`G^4-
M$*#A`#"3Y00PC>4`,*#C!_S_ZP``4.,%```*``#0Y0``4.,P`%`3`0"@`P``
MH!,!`"#B'#"?Y0`@D^4$,)WE`B`SX``PH.,!```:#-"-X@3PG>2@^O_KT)T!
M`,A'`0`!RJ#C#P`MZ03@+>4,P$W@\`^,Y3`0G^4,T$WB+,"?Y0``D>44,(WB
M$""=Y0$0H.,`P)SE!,"-Y0#`H.,`,(WEM_K_Z_\`H./!^O_K**`!`-"=`0``
MP*#C\$,MZ0'HH.,,P$W@#N!,X`'*3.(``(SE#@!<X?O__QHX``[E`=A-XAS0
M3>("$*#C`!"-Y0'HC>(\$9_E`""@XP`PH.,`$)'E%!".Y0`0H.,4X([B`)"@
MX8SZ_^L!8%#B`(#!XL@OH.'(/R;@`C!3X',P_^8","/@`C!3X`(@PN`#8%;@
M`H#(X```6.,R``"ZZ'"?Y0Q0C>(`$*#C!B"@X0@PH.$)`*#A`!"-Y7?Z_^L!
M`''C`0!P`RP```K`()_E!1"@X0D`H.$Q^O_K`0!PXR0```H'`%#C&@``F@@`
M0.(`0)7@`P``.A8``.H!0$3B!0!4X1,``#H((*#C!Q"@X00`H.$]^O_K``!0
MX_;__QH%0$3@!@"4X,0?J.`!R(WB5#"?Y13`C.(`()/E`#"<Y0(@,^``,*#C
M#@``&@'8C>(<T(WB\(.]Z`%H5N(`@,CB`0!XXP$(=@/.__\:``#@XP`0H.'L
M___J&`"?Y8W__^L4`)_EB___ZRGZ_^O0G0$`"*`!``@``0!42`$`1$@!``'*
MH.,00"WI#,!-X/@/C.7^^?_K]_G_ZP``4.,``)`5$("]Z`'*H.-P0"WI#,!-
MX-@/C.7P,)_E&-!-X@!0H.$0$(WBY`"?Y0`PD^44,(WE`#"@XV3[_^L`0%#B
M#@``"@`PU.4``%/C"P``"@40H.'7^?_K``!0XQ(```JH,)_E`""3Y10PG>4"
M(#/@`#"@XR0``!H8T(WB<("]Z(@PG^4`()/E%#"=Y0(@,^``,*#C!1"@`70`
MGP4:```:&-"-XG!`O>CZ^__J!0"@X2GZ_^L`8*#A!`"@X2;Z_^L``(;@`@"`
MXA'Z_^M$P)_E1#"?Y0`@X.,!$*#C"$"-Y2`0C>@`8*#A*OK_ZQPPG^4`()/E
M%#"=Y0(@,^``,*#C!A"@`0@`GP7D__\*V?G_Z]"=`0!@2`$`=$<!`'A'`0`!
MRJ#C\$\MZ0S`3>#P#HSEB#6?Y8@EG^7LT$WB`""2Y>0@C>4`(*#C`&"@X0<`
MD^B`4(WB#$"#XB3`@^('`(7HF."-X@\`M.B,<(WB#P"NZ`,`E.@#`([H!P"<
MZ`<`A^@8$(WB/`6?Y1#[_^L`0%#B`@``"@`PU.4``%/C^@``&I/Y_^N,^?_K
M``!0XV\```H`@)#E``!8XVP```H(`*#AY?G_ZX``H.$!`(#BT/G_ZP#`V.4`
M`%SC`$"@X0!PH.$*```*X)2?Y00`H.$`P(WE"3"@X0`@X.,!$*#CY?G_ZP'`
M^.4"0(3B``!<X_7__QJX!)_EF("-X@(``.H$`+CE``!0XPT```H8$(WBY_K_
MZP!`4.+X__\*`##4Y0``4^/U__\*%_O_ZP``4./R__\*!`"@X83Y_^L`0%#B
M#```&@1`E>0``%3C"0``"@`PU.4``%/CM0``"@0`H.$)^__K``!0X_'__QH$
M0)7D``!4X_7__QH$`*#AK_G_ZS"4G^4`H*#A!P"@X:OY_^L`H(K@`:N*X@2@
MBN(*`*#AE/G_ZQ`TG^4`(.#C`1"@XP@PC>4,<(WE`#2?Y0!`C>4$D(WE`("@
MX:OY_^L'':#C"`"@X;'Y_^L!`'#C`P``&J+Y_^L`$)#E$0!1XY8``!H8$(WB
M"`"@X47Y_^L`4%#B)P``"K@3G^4`,);EM".?Y0``D>4!$*#C`("-Y;'Y_^L`
M<*#C?#.?Y0`@D^7D,)WE`B`SX``PH./6```:!P"@X>S0C>+PC[WH0/G_ZP"`
M4.)Y```:!`"7Y```4.,)```*&!"-XI+Z_^L`,%#B^/__"@`PT^4``%/C\O__
M&@0`E^0``%#C]?__&@T`H.-9^?_K-(.?Y5/`H.,`0*#A`'"@X8C__^HH,)WE
M#SH#X@$)4^/3__\:,$"=Y0;Y_^L``%3AS___&B@PG>6#.Z#AHSN@X0<-4^/*
M__\:"@"@X47Y_^L8$(WB`'"@X>`"G^5P^O_K`!!0XF@```H``);E4/S_ZP"@
M4.)D```*"@"@X4OY_^L#`%#C`$"@X0L``)H$`$#BK!*?Y0``BN#A^/_K``!0
MXP4``!H$`%3CB```"@1`BN`%,%3E+P!3XX0```J$`I_E&!"-XE;Z_^L``%#C
M`P``"@`PT.4P`%/C``!3$P0``!H*`*#A`!"@XQOY_^L`0%#B1P``&E`2G^5(
M`I_E^OK_ZR3Y_^M$8I_E1#*?Y0`@X.,!$*#C\(#-X0Q@C>4THI_E"`"-Y0<`
MH.$O^?_K#@``ZBKY_^L`,)#E$0!3XQ```!H4^?_K`1"@XP%0A>`*,*#A!""@
MX1!@C>4,4(WE`,"@X0<`H.$`$XWH'_G_ZP<=H.,'`*#A)?G_ZP$`<.,`0*#A
MZO__"@@`H.&T^/_KB`&?Y0<0H.'4^O_K!P"@X:[^_^M[___J`T"@X4[__^K_
M^/_K@`"@X0$`@.(8___J<`&?Y0`PEN60(9_E``"0Y000C>4`@(WE`1"@XQ[Y
M_^MK___JG?[_ZRPQG^4`()/EY#"=Y0(@,^``,*#C0@``&@0`H.'LT(WB\$^]
MZ*SX_^H`H);EF/__ZB+^_^L`H%'B`&"@X;/__[H*(%#B`+"@XP`PRN($`*#A
M`+"-Y;[X_^L&(*#CL!"-X@0`H.%[^/_K!@!0XRT``!H$,9_EL""=Y0,`4N&C
M__\:M"O=X?0PG^4#`%+AG___&C(@5N(`,,KB!`"@X0"PC>6K^/_K!`"@X;A`
MC>(H(*#C!!"@X6?X_^LH`%#C&0``&J0@G^6X,)_E#""-Y0$0H.,`(.#C!P"@
MX0A`C>7P@,WAX+#-Y<?X_^NL___J!$"6Y0``5.-W__\*!`"@X;+X_^L#`%#C
M<___F@0`0.)T$)_E``"$X$GX_^L``%#C!*"@`6S__^IO^/_K7`"?Y<[]_^O`
MAP$`T)T!`%A'`0!X2`$`%$@!`(!'`0",2`$`@$@!`"B@`0#02`$`<$@!`"1)
M`0`L20$`R$<!`*A)`0`02@$`6$D!`&A)`0"42`$``$-!0TA%``!(20$`-$D!
M`#Q)`0`!RJ#C<$`MZ0S`3>#H#XSE)"*?Y0C03>(@,I_E`""2Y00@C>4`(*#C
MN00`ZP,PG^<-$*#A`T"0YP0"G^5H,-3E:3#$Y9GY_^L``%#C`@``"@`PT.4Q
M`%/C80``"E[\_^O@,9_EJ@0`ZP,PG^<#0)#G!`"@X=`1G^4#,*#C`2"@XV'X
M_^L`0%#B#0``"KPQG^40()3EG@0`ZP,PG^<`$)+E`%"@X:@AG^4#`)#G._C_
MZQ`PE.4`$)/E"#"1Y0$%$^-2```:C"&?Y9$$`.N($9_E`B"?YP!0H.$#,*#C
M`@"0YP$@H.-(^/_K`$!0X@H```IH`9_E#1"@X6SY_^L`(%#B.P``"E@QG^40
M$)3E`S"?YP`0D>4#`)7G(/C_ZT11G^5$,9_E>@0`ZT`1G^4#,)_G`$"@X0$@
MH.,#8)#G!@"@X4;X_^LH(9_E`!"@X08`H.$2^/_K'#&?Y0`@H.,8`9_E`S"?
MYPT0H.$#,)3G:2##Y4[Y_^L``%#C`$"@X0@`A>4/```*!QV@XP0`H.%"^/_K
M`2"`XA$`4.,!`%(3`#"@X2```(J0,)_E`""3Y00PG>4"(#/@`#"@XQD``!H(
MT(WB<("]Z`0`E>4,_O_K``!0XP!`H.$(`(7EZ?__&IP`G^4G^/_K`3#0Y0``
M4^.?__\*F?__ZFQ0G^40()3E!#"5Y0``DN4`$)/E7?K_Z\/__^IL,)_E`S"?
MYP,`E><J^/_KI___ZLOW_^L$()7E5`"?Y0`0DN4$(*#A$?C_Z]"=`0"4;```
MK$<!`%AL``!\20$`*&P``(!)`0#P:P``B$D!`&1'`0"T:P``,*`!`)1K``",
M20$`I$D!`&!K``!81P$`K$D!`*QJ``#020$``<J@XS!`+>D,P$W@Z`^,Y>`P
MG^4,T$WB`$"@X0T0H.'4`)_E`#"3Y00PC>4`,*#C^_C_ZP`P4.(*```*`##3
MY0``4^,P`%,3`3"@`P`PH!,!,"/B``!4XP`PH`,!,`,2``!3XP<``!J(,)_E
M`""3Y00PG>4"(#/@`#"@XQP``!H,T(WB,("]Z``PU.4``%/C]/__"@0`H.%<
M^__K+Q"@XP!0H.']]__K``!0XP%0@!(%`*#A@??_ZT`0G^4$(*#C`OC_ZP``
M4./F__\:)#"?Y0`@D^4$,)WE`B`SX``PH.,#```:!`"@X0S0C>(P0+WH)?G_
MZG3W_^O0G0$`R$<!`(Q(`0```````<J@X_!/+>D,P$W@2`V,Y20\G^6EWTWB
M`!"@X8!@@>)``(#B"""-X@`PD^6,,HWE`#"@XP!0H.,$P!#E".`0Y0@`@.(L
M-*#A_SP#XBP\@^$,1*#A##R#X?](!.(^S[_F!#"#X08`4.$`P(+E!%""Y0@P
M@N4,4(+E$"""XNW__QHA/HWB`#"-Y8`PG>4$$(WE<("=Y70@G>40L)WE>'"=
MY7Q@G>6$P)WE"%"=Y0Q`G>44H)WE$`"-X@,0H.$!``#J";"@X0.@H.$!,*#A
M/."0Y3@0D.4(D+#E"1`AX`@0(>`'@*#A`W"@X0`PH.-T,(#E!#"0Y040(>`#
MX"[@`N`NX`3@+N`&(*#A#&"@X:'/H.&.P(SA`1"1X`P0@>$`P)WE"U"@X0``
M7.$*0*#A`,"@XW`0@.7A__\:!!"=Y?PZG^4(()WE`)"1Y0$(D>D@P)'E`R"2
MX`P@DN"IS:#A$("1Y1B@D>6`PHSA#$"1Y8G"C.$"P)S@"B`HX"OAH.$+(`+@
M"B`BX`3OCN$"P)S@"^^.X1`@G>4I0:#A`$^$X0X`*.`#()+@"0``X`@`(.`*
M()+@"4^$X0`@DN`8`)WE!%`NX`,`D.`,4`7@["V"X`Y0)>`(`)#@!0"0X.)=
M@.`@`)WEL&"=Y0,`D.`.`)#@;.$DX`+@#N`$X"[@#N"0X"@`G>5B(:#A`P"0
MX`0`D.!L02+@!4`$X.7MCN!L023@!`"0X.Y-@.`P`)WE`P"0X&P!@.!EP2+@
M#L`,X`+`+.`,`)#@.,"=Y6[AH.$#P)S@`B"<X&7!+N`$P`S@Y`V`X&7!+.`,
M()+@X,V"X$`@G>4#()+@92&"X&11+N``4`7@#E`EX`4@DN!(4)WE8`&@X0-0
ME>`.X)7@9%$@X`Q0!>#L+8+@9%$EX`7@GN#B78[@4."=Y0/@GN!DX8[@;$$@
MX`)`!.``0"3@!.">X%A`G>5B(:#A`T"4X```E.!L02+@!4`$X.7MCN!L023@
M!`"0X.Y-@.!@`)WE`P"0X&P!@.!EP2+@#L`,X`+`+.`,`)#@:,"=Y6[AH.$#
MP)S@`B"<X&7!+N`$P`S@Y`V`X&7!+.`,()+@X,V"X'`@G>4#()+@92&"X&11
M+N``4`7@#E`EX`4@DN!X4)WE8`&@X0-0E>`.X)7@9%$@X`Q0!>#L+8+@9%$E
MX`7@GN#B78[@@."=Y0/@GN!DX8[@;$$@X`)`!.``0"3@!$">X(C@G>5B(:#A
M`^">X```GN!LX2+@!>`.X.5-A.!LX2[@#@"0X.3M@."0`)WE`P"0X&P!@.!E
MP2+@!,`,X`+`+.`,`)#@F,"=Y61!H.$#P)S@`B"<X&7!).`.P`S@[@V`X&7!
M+.`,()+@X,V"X*`@G>4#,)+@;B$DX``@`N`$("+@93&#X`(PD^#L+8/@J%"=
MY1@XG^5@`:#A`U"5X`10E>!N02#@#$`DX`1`E>`#4);@;E&%X+A@G>5LX2#@
M`N`NX.)-A.`.X)7@8B&@X0-0EN``4)7@P&"=Y6P!(N#D[8[@!``@X```E>`#
M8);@[EV`X&S!AN!D`2+@R&"=Y0X`(.```)S@;N&@X0/`EN`"P)S@T&"=Y60A
M+N`%("+@Y0V`X`(@G.`#P);@9,&,X-A@G>5E02[@X"V"X`!`).`$0)S@8`&@
MX0/`EN`.P)S@X&"=Y>+MA.!E02#@`D`DX`1`G.`#P);@9<&,X.A@G>5B42#@
M#E`EX`50G.!NP:#A`V"6X.Y-A.```);@8N$LX/!@G>4$X"[@#N"0X`-@EN#D
M787@9`$LX&(AAN#X8)WE!0`@X.7MCN``()+@90&@X0-@EN`,8);@9,$@X.XM
M@N``<9WE#L`LX`S`EN#B;8S@`W"7X`A1G>5NP2#@9$&'X`+`+.`,P)3@8B&@
MX0-`E>``0)3@$%&=Y6X!(N#FS8S@!@`@X```E.`#4)7@[$V`X&[AA>!F`2+@
M&%&=Y0P`(.```)[@;,&@X0/@E>`"X)[@(%&=Y68A+.`$("+@`B">X`/@E>#D
M#8#@9N&.X&11+.`H89WE`%`EX.`M@N`%4)[@8`&@X0-@EN`,P);@9.$@X#!A
MG>4"X"[@XEV%X`[@G.`#P);@9,&,X#AAG>5B02#@Y>V.X`5`).`$0)S@95&@
MX0/`EN``P)S@0&&=Y>X-A.!B027@#D`DX`1`G.`#,);@8C&#X&XA)>``("+@
M`B"3X$C!G>7,-9_EX$V$X`/`G.!@`:#A!<"<X&Y1@.%N80#@4'&=Y010!>`&
M4(7A!<"<X`-0E^#D+8+@;E&%X&3A@.%D80#@6'&=Y0+@#N#BS8S@!N".X6(A
MH.$%4)[@`^"7X`#@GN#L#87@9%&"X61A`N`,4`7@8'&=Y090A>$.4)7@;.&"
MX0-PE^!L80+@`.`.X.!=A>!D08?@!N".X03@GN#E;8[@:.&=Y6`!H.$#X)[@
M`B">X&SA@.%L00#@<'&=Y07@#N`$X([A`N">X`-PE^!E(8#AYDV.X&S!A^!E
MX0#@>'&=Y08@`N`.((+A9F&@X0S`DN`#()?@`""2X.0-C.!EP8;A9>$&X(!Q
MG>4$P`S@#L",X0+@G.`#P)?@9"&&X67!C.``(`+@9%$&X.#MCN`%((+A#""2
MX.[-@N"((9WE8`&@X611@.$#()+@!B"2X)!QG>5D80#@#E`%X`90A>$"4)7@
M`W"7X&XA@.%N80#@9$&'X`P@`N"8<9WE[%V%X`8@@N%LP:#A!$"2X`,@E^``
M()+@Y0V$X&Y!C.%N80S@!4`$X*!QG>4&0(3A`D"4X&4AC.'@;83@`W"7X&5!
M#.``(`+@;N&'X`0@@N$.()+@YNV"X*@AG>5@`:#A`R"2X`P@DN!EP8#A94$`
MX+!QG>4&P`S@!,",X0)`G.`#P)?@9B&`X;AQG>5EP8S@#B`"X&91`.#N383@
M!2""X6[AH.$,P)+@`R"7X``@DN#D#8S@9L&.X691#N#`<9WE!,`,X`7`C.$"
M4)S@`\"7X&0ACN%FP8S@`"`"X&1A#N#@787@!B""X0P@DN#ES8+@R"&=Y6`!
MH.$#()+@`&"@XPX@DN!DX8#AT'&=Y07@#N`$8('E#&"!Y11@@>4<8('E9&$`
MX`;@CN$"X)[@`W"7X&4A@.%E80#@9$&'X`P@`N#8<9WE!B""X>SMCN`$0)+@
M;,&@X0,@E^``()+@90&,X65A#.`.``#@X'&=Y08`@.'N383@`@"0X&XAC.$#
M<)?@;F$,X`0@`N#0,I_EY`V`X&51A^`&((+AZ'&=Y61!H.$%()+@X%V"X/!A
MG>5N(23@`W"7X`S`E^``("+@`B"<X`/`EN!NP8S@^&&=Y>7M@N!@(23@!2`B
MX`(@G.!E4:#A`V"6X`1`EN!@P27@`&*=Y0[`+.`,P)3@`T"6X.XM@N!@083@
M"&*=Y6X!)>`"`"#@XLV,X```E.!B(:#A`V"6X`50EN!N02+@$&*=Y0Q`).`$
M0)7@`U"6X.P-@.`88IWE;E&%X&SA(N``X"[@X$V$X`[@E>!@`:#A`U"6X`)0
ME>`@8IWE;"$@X.3MCN`$("+@`B"5X`-@EN#N78+@;,&&X&0A(.`H8IWE#B`B
MX`(@G.!NX:#A`\"6X`#`G.`P8IWE9`$NX.4M@N`%`"#@``"<X`/`EN!DP8S@
M.&*=Y>)-@.!E`2[@`@`@X```G.!B(:#A`V"6X`[@EN!EP2+@0&*=Y>0-@.`$
MP"S@#,">X`/@EN!EX8[@2&*=Y>!=C.!DP2+@`,`LX`S`GN!@`:#A`^"6X`+@
MGN!08IWE9"$@X.7-C.`%("+@`B">X`/@EN!DX8[@6&*=Y>Q-@N!E(2#@#"`B
MX`(@GN!LP:#A`^"6X`#@GN!@8IWE90$LX.0M@N`$`"#@``">X`/@EN!EX8[@
M:&*=Y>)=@.!D`2S@`@`@X```GN!B(:#A`^"6X`S@GN!P8IWE9,$BX`7`+.`,
MP)[@`^"6X.4-@.!DX8[@96$BX'A"G>4`8";@X,V,X`;@GN!@`:#A`T"4X`(@
ME.!E82#@@$*=Y0Q@)N#L[8[@!B"2X`,PE.!LH8K@"3"3X&S!(.#N+8+@#L`L
MX&4Q@^`,,)/@XCV#X"#`D>4+()+@;H&(X``P@>48H('E$("!Y0@@@>4L,)_E
M#`"0X`!@H.,@`('E)&"!Y0`@D^6,,IWE`B`SX``PH.,!```:I=^-XO"/O>AA
M]/_KT)T!`)EY@EJAZ]ENW+P;C];!8LH!RJ#C$$`MZ0S`3>#X#XSE@`"@XWWT
M_^L.>Y_M`""@XP![@.T->Y_M>""`Y0)[@.T,>Y_M!'N`[0Q[G^T&>X#M#'N?
M[0A[@.T,>Y_M"GN`[0Q[@.T0@+WH`2-%9P````")J\WO`````/[<NI@`````
M=E0R$`````#PX=+#`````````````````<J@X_!'+>D,P$W@X`^,Y2@PD.4"
MD*#A+""0Y8G!@^`#`%SA`#"@XP(@T^``4*#A,""0Y0%`H.$T$)#ER0^@X0$`
M`"H!()+B`!"AXBPPA>6I/J#A@#&#X0(PD^"@'J'@>`"5Y2C`A>4``%#C.("%
M`C`PA>4T$(7E(0``&C\`6>,Q``#:0)!)XBECH.$!<(;B!W.$X`00H.$(,*#A
M0$"$X@#@D>4$P)'E"`"1Y0P@D>40$('B!`!1X0#@@^4$P(/E"`"#Y0P@@^40
M,(/B\___&@%`H.$%`*#ADOS_ZP<`5.'K__\:!FUFX`:3B>`)(*#A!Q"@X0@`
MH.'C\__K>)"%Y?"'O>A`<&#B"0!7X0EPH*$X@(7B``"(X`<@H.$$$*#AV?/_
MZW@PE>4#,(?@0`!3XW@PA>7PA[T8!0"@X0>02>`'0(3@=_S_Z\O__^H$<*#A
MY?__Z@'*H./P02WI#,!-X.@/C.4H,)'E,'"1Y3B`@>*C(:#A/R`"XC-OO^8!
M,(+B`4"@X3@`4^-_$.#C`%"@X3=_O^8"$,CG/0``VD`@8^(`$*#C`P"(X"/T
M_^L$`*#A7/S_ZS@@H.,`$*#C"`"@X1WT_^L$`*#A<'"$Y71@A.54_/_K`S#4
MY00`H.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7E
MNC#4X04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40
M,)3E(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XP
MQ>48,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%
MY?!!O>AZ\__J`P"(X#@@8^(`$*#CY?/_Z\;__^H/"N#C'_!`X@@PG^4#,(_@
M`#"3Y8WS_^JP60``"$`MZ0B`O>@!``(`/@```$$````,````00```!$```!!
M````)P```$$````V````00````,```!!````!@```$$````5````00````\`
M``!!````#@```$$````F````00```!,```!!````*0```$$````"````00``
M`!D```!!````"@```$$````+````00``````````````)7,O)7,````O<')O
M8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%
M35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)
M0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#
M04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(`
M``!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@````!L<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0
M051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H``%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S)7-C
M86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``
M```8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP
M-C$```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10``
M``!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@
M>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ
M92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD
M4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA
M9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P
M,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S
M:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%
M.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P
M;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I
M(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D
M<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$[
M"GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L
M94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N
M86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*
M8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@
M(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]
M("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?
M<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\
M.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F
M:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET
M(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I
M('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)
M0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H
M(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG
M=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#
M04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#
M3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@
M34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`[
M"G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E
M="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R
M="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?
M1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E
M860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C
M:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*
M)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)
M3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L
M94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D
M(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D[
M"B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[
M8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U
M9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T
M97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@
M("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U
M9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S
M("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@
M9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@
M/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F
M:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S
M+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY
M("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M
M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I
M.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W
M)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD
M8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,
M12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N
M="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B
M)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]
M"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z
M:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2![
M"B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D
M("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F
M:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE
M7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ
M92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL
M"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E
M<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@
M;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P
M<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?
M;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&
M24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B
M=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)
M3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N
M86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE
M.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B([
M"GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D
M:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD
M<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@
M)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?
M=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP
M;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ
M<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@
M*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M
M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P
M=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!
M4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@
M97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?
M5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M<&5R;'AS:2YC````/$H!`%1'`0``````%$@!`!A(`0`P2@$`7$<!`#A*`0``
M````'$H!`"1*`0```````$-!0TA%```^````00````P```!!````$0```$$`
M```G````00```#8```!!`````P```$$````&````00```!4```!!````#P``
M`$$````.````00```"8```!!````$P```$$````I````00````(```!!````
M&0```$$````*````00````L```!!``````````````!<D/]_`0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#8&0$`L!D!````````````````
M``````````````````$````"`P```0```!(#```!````'`,```P```"D$P$`
M#0```%Q&`0`9````R)T!`!L````$````&@```,R=`0`<````!````/7^_V^T
M`0$`!0```*P+`0`&````3`4!``H```"B!```"P```!`````5``````````,`
M``#PG@$``@```/`!```4````$0```!<```"T$0$`$0```'P1`0`2````.```
M`!,````(````'@````@```#[__]O`0```/[__V\<$0$`____;P(```#P__]O
M3A`!````````````````````````````````````````````````````````
M`````````.B=`0```````````+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3
M`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!
M`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`
ML!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P
M$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3
M`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`L!,!`+`3`0"P$P$`````
M``````"P%@$````````````*4$%2+G!M"@````!$2@$`1T-#.B`H4F%S<&)I
M86X@,3,N,BXP+3<K<G!I,2D@,3,N,BXP`$$N````865A8FD``20````%-@`&
M!@@!"0$*`A($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A
M=&$N<F5L+G)O`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N
M05)-+F%T=')I8G5T97,`````````````````````````````````````````
M````````````````"P````$````"````5`$!`%0!```9```````````````!
M`````````!,````'`````@```'`!`0!P`0``)```````````````!```````
M```F````!P````(```"4`0$`E`$``"````````````````0`````````-```
M`/;__V\"````M`$!`+0!``"8`P``!0`````````$````!````#X````+````
M`@```$P%`0!,!0``8`8```8````!````!````!````!&`````P````(```"L
M"P$`K`L``*($``````````````$`````````3@```/___V\"````3A`!`$X0
M``#,````!0`````````"`````@```%L```#^__]O`@```!P1`0`<$0``8```
M``8````"````!`````````!J````"0````(```!\$0$`?!$``#@````%````
M``````0````(````<P````D```!"````M!$!`+01``#P`0``!0```!8````$
M````"````'P````!````!@```*03`0"D$P``#```````````````!```````
M``!W`````0````8```"P$P$`L!,``/P"``````````````0````$````@@``
M``$````&````L!8!`+`6``"L+P`````````````0`````````(@````!````
M!@```%Q&`0!<1@``"```````````````!`````````".`````0````(```!D
M1@$`9$8``"1"``````````````0`````````E@````$``'""````B(@!`(B(
M```(````#0`````````$`````````*$````!`````@```)"(`0"0B```!```
M````````````!`````````"K````#@````,```#(G0$`R(T```0`````````
M``````0````$````MP````\````#````S)T!`,R-```$```````````````$
M````!````,,````!`````P```-"=`0#0C0``%P``````````````!```````
M``#0````!@````,```#HG0$`Z(T```@!```&``````````0````(````V0``
M``$````#````\)X!`/".```0`0`````````````$````!````-X````!````
M`P````"@`0``D```&```````````````!`````````#D````"`````,````8
MH`$`&)```"@```````````````@`````````Z0````$````P`````````!B0
M```E```````````````!`````0```/(````#``!P```````````]D```+P``
M`````````````0`````````!`````P``````````````;)````(!````````
,``````$`````````
